cmd

package
v1.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 5, 2026 License: MIT Imports: 16 Imported by: 0

Documentation

Overview

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CollisionEffect

type CollisionEffect struct {
	Pos      FloatPosition // Position of the collision
	Timer    float64       // Animation timer
	Duration float64       // Total duration
}

type Dalek

type Dalek struct {
	GridPos   Position      // Current grid position
	VisualPos FloatPosition // Interpolated visual position (current frame)
	StartPos  FloatPosition // Starting position for animation
	TargetPos FloatPosition // Target visual position
	IsMoving  bool          // Whether currently animating
	MoveTimer float64       // Animation timer
	IsEmperor bool          // Whether this is the Dalek Emperor (can only be killed when all normal daleks are dead)
}

type DalekGameImages

type DalekGameImages struct {
	Human        *ebiten.Image
	Dalek        *ebiten.Image
	DalekEmperor *ebiten.Image
}

Daleks Images

func (*DalekGameImages) LoadImages

func (images *DalekGameImages) LoadImages() error

/ LoadImages initializes all crossword images and returns an error if any image fails to load

type FloatPosition

type FloatPosition struct {
	X, Y float64
}

type Game

type Game struct {
	// contains filtered or unexported fields
}

func NewGame

func NewGame() *Game

func (*Game) Draw

func (g *Game) Draw(screen *ebiten.Image)

func (*Game) Layout

func (g *Game) Layout(outsideWidth, outsideHeight int) (int, int)

func (*Game) Update

func (g *Game) Update() error

type GameState

type GameState int
const (
	StateMenu GameState = iota
	StatePlaying
	StateLevelComplete
	StateGameOver
	StateWin
)

type Position

type Position struct {
	X, Y int
}

type SoundPlayer

type SoundPlayer struct {
	// contains filtered or unexported fields
}

func NewSoundPlayer

func NewSoundPlayer() (*SoundPlayer, error)

func (*SoundPlayer) Play

func (s *SoundPlayer) Play(name string)

Jump to